@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from typing import Dict, List
-from aws_lambda_utils import BaseOptionalDataClass
+from aws_lambda_utils import BaseModelOptionalFields
 
 
 @dataclass
-class APIGatewayProxyResponse(BaseOptionalDataClass):
+class APIGatewayProxyResponse(BaseModelOptionalFields):
     StatusCode: int
     Headers: Dict[str, str]
     MultiValueHeaders: Dict[str, List[str]]
